@@ -1,7 +1,7 @@
+import re
 from functools import partial, reduce
 from math import gcd
-import re
-from operator import itemgetter
+from operator import attrgetter, itemgetter
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -19,7 +19,7 @@ from typing import (
 from ._loop import loop_last
 from ._pick import pick_bool
 from ._wrap import divide_line
-from .align import AlignValues
+from .align import AlignMethod
 from .cells import cell_len, set_cell_size
 from .containers import Lines
 from .control import strip_control_codes
@@ -29,12 +29,7 @@ from .segment import Segment
 from .style import Style, StyleType
 
 if TYPE_CHECKING:  # pragma: no cover
-    from .console import (
-        Console,
-        ConsoleOptions,
-        JustifyMethod,
-        OverflowMethod,
-    )
+    from .console import Console, ConsoleOptions, JustifyMethod, OverflowMethod
 
 DEFAULT_JUSTIFY: "JustifyMethod" = "default"
 DEFAULT_OVERFLOW: "OverflowMethod" = "fold"
@@ -182,6 +177,32 @@ class Text(JupyterMixin):
             return other.plain in self.plain
         return False
 
+    def __getitem__(self, slice: Union[int, slice]) -> "Text":
+        def get_text_at(offset) -> "Text":
+            _Span = Span
+            text = Text(
+                self.plain[offset],
+                spans=[
+                    _Span(0, 1, style)
+                    for start, end, style in self._spans
+                    if end > offset >= start
+                ],
+                end="",
+            )
+            return text
+
+        if isinstance(slice, int):
+            return get_text_at(slice)
+        else:
+            start, stop, step = slice.indices(len(self.plain))
+            if step == 1:
+                lines = self.divide([start, stop])
+                return lines[1]
+            else:
+                # This would be a bit of work to implement efficiently
+                # For now, its not required
+                raise TypeError("slices with step!=1 are not supported")
+
     @property
     def cell_len(self) -> int:
         """Get the number of cells required to render this text."""
@@ -521,10 +542,10 @@ class Text(JupyterMixin):
             Iterable[Segment]: Result of render that may be written to the console.
         """
 
+        _Segment = Segment
         text = self.plain
-        null_style = Style.null()
         enumerated_spans = list(enumerate(self._spans, 1))
-        get_style = partial(console.get_style, default=null_style)
+        get_style = partial(console.get_style, default=Style.null())
         style_map = {index: get_style(span.style) for index, span in enumerated_spans}
         style_map[0] = get_style(self.style)
 
@@ -540,7 +561,6 @@ class Text(JupyterMixin):
         stack_append = stack.append
         stack_pop = stack.remove
 
-        _Segment = Segment
         style_cache: Dict[Tuple[Style, ...], Style] = {}
         style_cache_get = style_cache.get
         combine = Style.combine
@@ -725,11 +745,11 @@ class Text(JupyterMixin):
         if count:
             self.plain = f"{self.plain}{character * count}"
 
-    def align(self, align: AlignValues, width: int, character: str = " ") -> None:
+    def align(self, align: AlignMethod, width: int, character: str = " ") -> None:
         """Align text to a given width.
 
         Args:
-            align (AlignValues): One of "left", "center", or "right".
+            align (AlignMethod): One of "left", "center", or "right".
             width (int): Desired width.
             character (str, optional): Character to pad with. Defaults to " ".
         """
@@ -809,11 +829,11 @@ class Text(JupyterMixin):
         self._length += len(text)
         return self
 
-    def append_tokens(self, tokens: Iterable[Tuple[str, StyleType]]):
+    def append_tokens(self, tokens: Iterable[Tuple[str, Optional[StyleType]]]):
         """Append iterable of str and style. Style may be a Style instance or a str style definition.
 
         Args:
-            pairs (Iterable[Tuple[str, StyleType]]): An iterable of tuples containing str content and style.
+            pairs (Iterable[Tuple[str, Optional[StyleType]]]): An iterable of tuples containing str content and style.
 
         Returns:
             Text: Returns self for chaining.
@@ -824,7 +844,8 @@ class Text(JupyterMixin):
         offset = len(self)
         for content, style in tokens:
             append_text(content)
-            append_span(_Span(offset, offset + len(content), style))
+            if style is not None:
+                append_span(_Span(offset, offset + len(content), style))
             offset += len(content)
         self._length = offset
         return self
@@ -861,21 +882,16 @@ class Text(JupyterMixin):
             return Lines([self.copy()])
         if not allow_blank and text.endswith(separator):
             text = text[: -len(separator)]
-        offsets: List[int] = []
-        append = offsets.append
-        offset = 0
-        while True:
-            try:
-                offset = text.index(separator, offset) + len(separator)
-            except ValueError:
-                break
-            append(offset)
+        offsets = [
+            match.start() + 1 for match in re.finditer(re.escape(separator), text)
+        ]
         lines = self.divide(offsets)
         if not include_separator:
             separator_length = len(separator)
             for line in lines:
                 if line.plain.endswith(separator):
                     line.right_crop(separator_length)
+
         return lines
 
     def divide(self, offsets: Iterable[int]) -> Lines:
@@ -887,55 +903,56 @@ class Text(JupyterMixin):
         Returns:
             Lines: New RichText instances between offsets.
         """
-
         if not offsets:
-            line = self.copy()
-            return Lines([line])
+            return Lines([self.copy()])
 
         text = self.plain
         text_length = len(text)
         divide_offsets = [0, *offsets, text_length]
         line_ranges = list(zip(divide_offsets, divide_offsets[1:]))
-        average_line_length = -(-text_length // len(line_ranges))
 
+        style = self.style
+        justify = self.justify
+        overflow = self.overflow
+        _Text = Text
         new_lines = Lines(
-            Text(
+            _Text(
                 text[start:end],
-                style=self.style,
-                justify=self.justify,
-                overflow=self.overflow,
+                style=style,
+                justify=justify,
+                overflow=overflow,
             )
             for start, end in line_ranges
         )
-        line_ranges = [
-            (offset, offset + len(line))
-            for offset, line in zip(divide_offsets, new_lines)
-        ]
-        for span in self._spans:
-            line_index = (span.start // average_line_length) % len(line_ranges)
+        if not self._spans:
+            return new_lines
+        order = {span: span_index for span_index, span in enumerate(self._spans)}
+        span_stack = sorted(self._spans, key=attrgetter("start"), reverse=True)
 
-            line_start, line_end = line_ranges[line_index]
-            if span.start < line_start:
-                while True:
-                    line_index -= 1
-                    line_start, line_end = line_ranges[line_index]
-                    if span.start >= line_start:
-                        break
-            elif span.start > line_end:
-                while True:
-                    line_index += 1
-                    line_start, line_end = line_ranges[line_index]
-                    if span.start <= line_end:
-                        break
+        pop = span_stack.pop
+        push = span_stack.append
+        _Span = Span
+        get_order = order.__getitem__
 
-            while True:
-                span, new_span = span.split(line_end)
-                new_lines[line_index]._spans.append(span.move(-line_start))
-                if new_span is None:
-                    break
-                span = new_span
-                line_index = (line_index + 1) % len(line_ranges)
-                line_start, line_end = line_ranges[line_index]
+        for line, (start, end) in zip(new_lines, line_ranges):
+            if not span_stack:
+                break
+            append_span = line._spans.append
+            position = len(span_stack) - 1
+            while span_stack[position].start < end:
+                span = pop(position)
+                add_span, remaining_span = span.split(end)
+                if remaining_span:
+                    push(remaining_span)
+                    order[remaining_span] = order[span]
+                span_start, span_end, span_style = add_span
+                line_span = _Span(span_start - start, span_end - start, span_style)
+                order[line_span] = order[span]
+                append_span(line_span)
+                position -= 1
+                if position < 0 or not span_stack:
+                    break  # pragma: no cover
+            line._spans.sort(key=get_order)
 
         return new_lines
 
